package WebGUI::i18n::Spanish::Asset_Thingy;
use utf8;
our $I18N = {
  'add field label' => {
    'lastUpdated' => '1253304989',
    'message' => 'Agregar Campo'
  },
  'add label' => {
    'lastUpdated' => '1253304994',
    'message' => 'Agregar'
  },
  'add other thing label' => {
    'lastUpdated' => '1253305004',
    'message' => 'Agregar otra Cosa:'
  },
  'add thing label' => {
    'lastUpdated' => '1253305009',
    'message' => 'Agregar Cosa'
  },
  'addThing_url' => {
    'lastUpdated' => '1253305040',
    'message' => 'El URL hacia la pantalla para agregar una Cosa nueva'
  },
  'add_url' => {
    'lastUpdated' => '1253305054',
    'message' => 'El URL para agregar cosas'
  },
  'after save description' => {
    'lastUpdated' => '1253305072',
    'message' => 'La&nbsp;pantalla que se muestra después de guardar esta Cosa'
  },
  'after save label' => {
    'lastUpdated' => '1253305079',
    'message' => 'Después de Guardar'
  },
  'assetName' => {
    'lastUpdated' => '1253305093',
    'message' => 'Cosas'
  },
  'back to thingy default view' => {
    'lastUpdated' => '1253305104',
    'message' => 'Volver a la vista por defecto de Cosas'
  },
  'cache timeout' => {
    'lastUpdated' => '1253305126',
    'message' => 'Tiempo Máximo en Cache'
  },
  'cache timeout help' => {
    'lastUpdated' => '1253305153',
    'message' => 'Debido a que todos los usuarios verán este recurso de la misma manera, podemos mantenerlo en cache por largos períodos de tiempo para mejorar el desempeño. ¿Cuánto tiempo debemos mantenerlo en cache?'
  },
  'canEditThings' => {
    'lastUpdated' => '1253305175',
    'message' => 'Un condicional que indica si el usuario puede ver Cosas definidas en esta Cosa.'
  },
  'canView' => {
    'lastUpdated' => '1253305193',
    'message' => 'Un condicional que indica si el usuario tiene privilegios para ver esta Cosa o no.'
  },
  'check duplicates label' => {
    'lastUpdated' => '1253305207',
    'message' => 'Comprobar Duplicados'
  },
  'default save button label' => {
    'lastUpdated' => '1253305211',
    'message' => 'Guardar'
  },
  'default thing label' => {
    'lastUpdated' => '1253305221',
    'message' => 'Cosa por Omisión'
  },
  'default value description' => {
    'lastUpdated' => '1253305229',
    'message' => 'Inserte el valor por defecto (si lo hubiera) para el campo. Si ha definido los valores posibles para este campo usando una función (hash), el valor por defecto será una llave de esa función y no un valor. Para los campos sí/no, seleccione "si" o "no".'
  },
  'default value label' => {
    'lastUpdated' => '1253305238',
    'message' => 'Valor por omisión'
  },
  'default value subtext' => {
    'lastUpdated' => '1253305248',
    'message' => 'Uno por línea'
  },
  'default view description' => {
    'lastUpdated' => '1253305280',
    'message' => 'Pantalla por defecto para esta Cosa. Puede ser la de búsqueda o la de agregar.'
  },
  'default view label' => {
    'lastUpdated' => '1253305289',
    'message' => 'Vista por Omisión'
  },
  'delete label' => {
    'lastUpdated' => '1253305296',
    'message' => 'Eliminar'
  },
  'delete thing data warning' => {
    'lastUpdated' => '1253305330',
    'message' => '¿Está seguro de querer borrar esta Cosa? Esta operación no entra en el control de versiones, así que no se podrá revertir.'
  },
  'delete thing warning' => {
    'lastUpdated' => '1253305352',
    'message' => '¿Está seguro de querer borar esta Cosa y todos sus contenidos? Esta operación no entra en el control de versiones y no se podrá revertir.'
  },
  'delete_confirm' => {
    'lastUpdated' => '1253305382',
    'message' => 'Contiene una propiedad onclick sobre el enlace de eliminar que agrega el diálogo de confirmación en JavaScript.'
  },
  'delete_url' => {
    'lastUpdated' => '1253305391',
    'message' => 'El URL para eliminar la Cosa.'
  },
  'display label' => {
    'lastUpdated' => '1253305397',
    'message' => 'Mostrar'
  },
  'displayInSearchFields_fieldId' => {
    'lastUpdated' => '1253305409',
    'message' => 'El <strong>fieldID</strong> para este Campo.'
  },
  'displayInSearchFields_label' => {
    'lastUpdated' => '1253305417',
    'message' => 'La etiqueta de este Campo.'
  },
  'displayInSearchFields_loop' => {
    'lastUpdated' => '1253305437',
    'message' => 'Un ciclo que contiene los Campos mostrados en los resultados de búsqueda.'
  },
  'displayInSearchFields_orderByUrl' => {
    'lastUpdated' => '1253305459',
    'message' => 'El URL para ordenar los resultados de búsqueda según este campo.'
  },
  'duplicates label' => {
    'lastUpdated' => '1253305469',
    'message' => '¿Qué hacer con los duplicados?'
  },
  'edit instructions description' => {
    'lastUpdated' => '1253305485',
    'message' => 'Instrucciones en la pantalla de edición acerca de agregar o editar una Cosa.'
  },
  'edit instructions label' => {
    'lastUpdated' => '1253305493',
    'message' => 'Instrucciones'
  },
  'edit label' => {
    'lastUpdated' => '1253305499',
    'message' => 'Editar'
  },
  'edit screen tab label' => {
    'lastUpdated' => '1253305509',
    'message' => 'Editar'
  },
  'edit screen title description' => {
    'lastUpdated' => '1253305521',
    'message' => 'El título de la pantalla de edición.'
  },
  'edit screen title label' => {
    'lastUpdated' => '1253305531',
    'message' => 'Título de la pantalla de edición'
  },
  'edit template description' => {
    'lastUpdated' => '1253305589',
    'message' => 'Seleccione la Plantilla utilizada para desplegar la Cosa.'
  },
  'edit template label' => {
    'lastUpdated' => '1253305598',
    'message' => 'Plantilla de Edición'
  },
  'edit thing template label' => {
    'lastUpdated' => '1253305610',
    'message' => 'Plantilla de Edición para Cosas'
  },
  'edit thing title' => {
    'lastUpdated' => '1253305619',
    'message' => 'Editar o Agregar Cosa'
  },
  'editInstructions' => {
    'lastUpdated' => '1253305630',
    'message' => 'Instrucciones acerca de la edición de esta Cosa.'
  },
  'editScreenTitle' => {
    'lastUpdated' => '1253305643',
    'message' => 'El título de la pantalla de edición.'
  },
  'edit_url' => {
    'lastUpdated' => '1253305656',
    'message' => 'El URL para la pantalla de edición de la Cosa actual.'
  },
  'error_loop' => {
    'lastUpdated' => '1253305680',
    'message' => 'Un ciclo que contiene información sobre los errores, por ejemplo cuando el usuario no completa un campo obligatorio.'
  },
  'error_message' => {
    'lastUpdated' => '1253305700',
    'message' => 'Un mensaje de error indicando aquello que el usuario hizo incorrectamente.'
  },
  'export label' => {
    'lastUpdated' => '1253305705',
    'message' => 'Exportar'
  },
  'export metadata description' => {
    'lastUpdated' => '1253305726',
    'message' => '¿El exportado debe incluir los campos de metadatos?'
  },
  'export metadata label' => {
    'lastUpdated' => '1253305735',
    'message' => '¿Exportar meta-datos?'
  },
  'export_url' => {
    'lastUpdated' => '1253305768',
    'message' => 'El URL para exportar a un archivo CSV los datos en el resultado de búsqueda. Solamente está disponible después que la búsqueda ha sido efectuada.'
  },
  'extras description' => {
    'lastUpdated' => '1253305799',
    'message' => 'Agregue marcas adicionales para el campo, e.g. \'class="miClase"\''
  },
  'extras label' => {
    'lastUpdated' => '1253305805',
    'message' => 'Extras'
  },
  'field in other thing label' => {
    'lastUpdated' => '1253305813',
    'message' => 'Campo en Otra Cosa'
  },
  'field label description' => {
    'lastUpdated' => '1253305824',
    'message' => 'La etiqueta para este Campo.'
  },
  'field label label' => {
    'lastUpdated' => '1253305830',
    'message' => 'Etiqueta'
  },
  'field status description' => {
    'lastUpdated' => '1253305883',
    'message' => 'Los campos ocultos no serán visibles al usuario. Los campos visibles pueden ser vistos pero no modificados. Los campos editables pueden ser completados por el usuario. Los campos obligatorios deben ser completados por el usuario. Si selecciona Oculto o Visible, recuerde indicar Valor por Omisión.'
  },
  'field status label' => {
    'lastUpdated' => '1253305889',
    'message' => 'Estado'
  },
  'field type description' => {
    'lastUpdated' => '1253305919',
    'message' => 'Seleccione el tipo de elemento de formulario para este Campo. También puede aprovecharse para validar la entrada del usuario.'
  },
  'field type label' => {
    'lastUpdated' => '1253305926',
    'message' => 'Tipo de Campo'
  },
  'field_form' => {
    'lastUpdated' => '1253305950',
    'message' => 'El elemento del formulario asociado a este Campo.'
  },
  'field_id' => {
    'lastUpdated' => '1253305961',
    'message' => 'El ID para este Campo.'
  },
  'field_isHidden' => {
    'lastUpdated' => '1253305975',
    'message' => 'Un condicional que indica si este Campo es oculto o no.'
  },
  'field_isRequired' => {
    'lastUpdated' => '1253305989',
    'message' => 'Un condicional que indica si este Campo es Requerido o no.'
  },
  'field_isVisible' => {
    'lastUpdated' => '1253306010',
    'message' => 'Un condicional que indica si este campo es visible o no.'
  },
  'field_label' => {
    'lastUpdated' => '1253306019',
    'message' => 'La etiqueta de este Campo.'
  },
  'field_loop' => {
    'lastUpdated' => '1253306030',
    'message' => 'Un ciclo que contiene los Campos visibles de esta Cosa.'
  },
  'field_name' => {
    'lastUpdated' => '1253306042',
    'message' => 'El nombre del elemento de formulario para este Campo.'
  },
  'field_pretext' => {
    'lastUpdated' => '1253306077',
    'message' => 'Una descripción adicional del Campo para que los usuarios sepan como completarlo. Aparecerá encima o antes del elemento de formulario asociado.'
  },
  'field_subtext' => {
    'lastUpdated' => '1253306090',
    'message' => 'Una descripción adicional del Campo para que los usuarios sepan como
completarlo. Aparecerá debajo o después del elemento de formulario
asociado.'
  },
  'field_type' => {
    'lastUpdated' => '1253306109',
    'message' => 'El tipo del Campo (Archivo, Texto, etc.)'
  },
  'field_url' => {
    'lastUpdated' => '1253306137',
    'message' => 'Un URL opcional al cual este campo hace referencia, por ejemplo para enlazar con Campos de otras Cosas.'
  },
  'field_value' => {
    'lastUpdated' => '1253306147',
    'message' => 'El valor de este Campo.'
  },
  'fields label' => {
    'lastUpdated' => '1253306153',
    'message' => 'Campos'
  },
  'fields tab label' => {
    'lastUpdated' => '1253306158',
    'message' => 'Campos'
  },
  'fieldstatus editable label' => {
    'lastUpdated' => '1253306164',
    'message' => 'Editable'
  },
  'fieldstatus hidden label' => {
    'lastUpdated' => '1253306170',
    'message' => 'Oculto'
  },
  'fieldstatus required label' => {
    'lastUpdated' => '1253306176',
    'message' => 'Requerido'
  },
  'fieldstatus visible label' => {
    'lastUpdated' => '1253306182',
    'message' => 'VIsible'
  },
  'file contains label' => {
    'lastUpdated' => '1253306196',
    'message' => 'Archivo Contiene'
  },
  'form_end' => {
    'lastUpdated' => '1253306221',
    'message' => 'El fragmento HTML para el final de la forma'
  },
  'form_start' => {
    'lastUpdated' => '1253306229',
    'message' => 'El fragmento HTML para el inicio de la forma.'
  },
  'form_submit' => {
    'lastUpdated' => '1253306238',
    'message' => 'El botón de envío de la forma.'
  },
  'has entered max per user message' => {
    'lastUpdated' => '1253306261',
    'message' => 'Alcanzó el máximo número permitido de registros.'
  },
  'height description' => {
    'lastUpdated' => '1253306289',
    'message' => 'Altura de este campo en pixels, aplicable solamente a Text Areas y HTML Areas.'
  },
  'height label' => {
    'lastUpdated' => '1253306294',
    'message' => 'Altura'
  },
  'height subtext' => {
    'lastUpdated' => '1253306312',
    'message' => 'Texto opcional para describir un Text Area o HTML Area.'
  },
  'ignore first line label' => {
    'lastUpdated' => '1253306320',
    'message' => '¿Ignorar la primera línea?'
  },
  'import file label' => {
    'lastUpdated' => '1253306330',
    'message' => 'Seleccione el archivo a importar'
  },
  'import label' => {
    'lastUpdated' => '1253306336',
    'message' => 'Importar'
  },
  'import_url' => {
    'lastUpdated' => '1253306359',
    'message' => 'El URL para importar datos en esta Cosa desde un archivo CSV.'
  },
  'is required error' => {
    'lastUpdated' => '1253306370',
    'message' => 'es requerido'
  },
  'isCurrent' => {
    'lastUpdated' => '1253306391',
    'message' => 'Un condicional que indica si esta Cosa es la que el usuario está manipulando o no.'
  },
  'listOfThings' => {
    'lastUpdated' => '1253306407',
    'message' => 'Un ciclo que contiene una lista de todas las Cosas en esta Cosa.'
  },
  'manage things label' => {
    'lastUpdated' => '1253306415',
    'message' => 'Administrar Cosas'
  },
  'manage_url' => {
    'lastUpdated' => '1253306439',
    'message' => 'El URL que conduce a la página de administrar Cosas en esta Cosa.'
  },
  'max entries per user description' => {
    'lastUpdated' => '1253306453',
    'message' => 'Máximo número de registros que un usuario puede agregar a esta Cosa.'
  },
  'max entries per user label' => {
    'lastUpdated' => '1253306467',
    'message' => 'Número máximo de registros por usuario'
  },
  'name' => {
    'lastUpdated' => '1253306475',
    'message' => 'El nombre de la Cosa'
  },
  'no field values message' => {
    'lastUpdated' => '1253306485',
    'message' => 'El Campo no tiene valores.'
  },
  'no permission to edit' => {
    'lastUpdated' => '1253306495',
    'message' => 'No tiene privilegios para editar esta Cosa.'
  },
  'no permission to search' => {
    'lastUpdated' => '1253306504',
    'message' => 'No tiene privilegios para buscar en esta Cosa.'
  },
  'on add workflow description' => {
    'lastUpdated' => '1253306520',
    'message' => 'Flujo de trabajo activado después de agregar esta Cosa.'
  },
  'on add workflow label' => {
    'lastUpdated' => '1253306534',
    'message' => 'Al Agregar'
  },
  'on delete workflow description' => {
    'lastUpdated' => '1253306545',
    'message' => 'Flujo de trabajo activado al eliminar esta Cosa.'
  },
  'on delete workflow label' => {
    'lastUpdated' => '1253306553',
    'message' => 'Al Eliminar'
  },
  'on edit workflow description' => {
    'lastUpdated' => '1253306565',
    'message' => 'Flujo de trabajo activado al editar esta Cosa.'
  },
  'on edit workflow label' => {
    'lastUpdated' => '1253306571',
    'message' => 'Al Editar'
  },
  'other thing field missing message' => {
    'lastUpdated' => '1253306582',
    'message' => 'El Campo de la otra Cosa no existe.'
  },
  'other thing missing message' => {
    'lastUpdated' => '1253306617',
    'message' => 'La Cosa a la cual hace referencia este Campo no existe, no tiene tabla asociada o el Campo en dicha tabla fue eliminado.'
  },
  'overwrite label' => {
    'lastUpdated' => '1253306623',
    'message' => 'Reemplazar'
  },
  'owner' => {
    'lastUpdated' => '1255726214',
    'message' => 'Propietario'
  },
  'possible values description' => {
    'lastUpdated' => '1253306715',
    'message' => 'Este campo es utilizado para indicar los tipos (como Checkbox List y Select List). Ingrese los valores que desea mostrar, uno por línea.<br><br>Si quiere una etiqueta diferente para cada valor, la lista de valores posibles debe tener el formato<br><br>{<br>&nbsp; "etiqueta1" =&gt; "valor1",<br>&nbsp; "etiqueta2" =&gt; "valor2",<br>&nbsp; ...<br>}<br>'
  },
  'possible values label' => {
    'lastUpdated' => '1253307316',
    'message' => 'Valores Posibles'
  },
  'possible values subtext' => {
    'lastUpdated' => '1253307324',
    'message' => 'Uno por línea.'
  },
  'pretext description' => {
    'lastUpdated' => '1253307362',
    'message' => 'Una etiqueta adicional, quizás una descripción de lo que debe ir en el campo. Será presentada encima o antes del elemento de formulario asociado.'
  },
  'pretext label' => {
    'lastUpdated' => '1253309231',
    'message' => 'Texto previo'
  },
  'save button label description' => {
    'lastUpdated' => '1253307393',
    'message' => 'La etiqueta del botón de guardar en la pantalla de edición.'
  },
  'save button label label' => {
    'lastUpdated' => '1253308241',
    'message' => 'Etiqueta para Botón de Guardar'
  },
  'search button label' => {
    'lastUpdated' => '1253308280',
    'message' => 'Buscar'
  },
  'search description description' => {
    'lastUpdated' => '1253308549',
    'message' => 'Descripción de la pantalla de búsqueda.'
  },
  'search description label' => {
    'lastUpdated' => '1253308559',
    'message' => 'Descripción'
  },
  'search label' => {
    'lastUpdated' => '1253308586',
    'message' => 'Buscar'
  },
  'search other thing label' => {
    'lastUpdated' => '1253308595',
    'message' => 'Buscar Otra Cosa:'
  },
  'search screen tab label' => {
    'lastUpdated' => '1253308607',
    'message' => 'Pantalla de Búsqueda'
  },
  'search screen title description' => {
    'lastUpdated' => '1253308643',
    'message' => 'El título de la pantalla de búsqueda'
  },
  'search screen title label' => {
    'lastUpdated' => '1253308660',
    'message' => 'Título para Pantalla de Búsqueda'
  },
  'search template description' => {
    'lastUpdated' => '1253308693',
    'message' => 'Seleccione la Plantilla utilizada para desplegar la pantalla de búsqueda para esta Cosa.'
  },
  'search template label' => {
    'lastUpdated' => '1253308705',
    'message' => 'Plantilla para Búsqueda'
  },
  'search thing label' => {
    'lastUpdated' => '1253308714',
    'message' => 'Búsqueda'
  },
  'search thing template label' => {
    'lastUpdated' => '1253308726',
    'message' => 'Plantilla para Búsqueda de Cosas'
  },
  'search this thing label' => {
    'lastUpdated' => '1253308734',
    'message' => 'Buscar en esta Cosa'
  },
  'searchDescription' => {
    'lastUpdated' => '1253308748',
    'message' => 'Una descripción de la pantalla de búsqueda'
  },
  'searchFields_fieldId' => {
    'lastUpdated' => '1253308762',
    'message' => 'El <strong>fieldID</strong> de un campo sobre el cual se puede buscar.'
  },
  'searchFields_form' => {
    'lastUpdated' => '1253308804',
    'message' => 'Un elemento de formulario para buscar sobre este campo, concordante con el <strong>fieldType</strong> de este campo.'
  },
  'searchFields_is__fieldType__' => {
    'lastUpdated' => '1253308884',
    'message' => 'Un condicional que indica si este campo es del tipo <strong>__fieldType__</strong>.&nbsp; La primera letra de <strong>__fieldType__</strong> siempre es mayúscula. Por ejemplo, para un Select Box el valor de<br><br>&lt;tmpl_var searchFields_isSelectBox&gt;<br><br>sería cierto.'
  },
  'searchFields_label' => {
    'lastUpdated' => '1253308903',
    'message' => 'La etiquetda de un campo sobre el cual se puede buscar.'
  },
  'searchFields_listType' => {
    'lastUpdated' => '1280335612',
    'message' => 'Un condicional que indica si el campo es de tipo Lista.'
  },
  'searchFields_loop' => {
    'lastUpdated' => '1253308916',
    'message' => 'Un ciclo que contiene los campos sobre los cuales se puede buscar.'
  },
  'searchFields_textForm' => {
    'lastUpdated' => '1253308935',
    'message' => 'Un campo de entrada de texto para buscar sobre este Campo.'
  },
  'searchResult_copy_icon' => {
    'lastUpdated' => '1253308950',
    'message' => 'El ícono de copiar para copiar el resultado de la búsqueda.'
  },
  'searchResult_copy_url' => {
    'lastUpdated' => '1253308964',
    'message' => 'El URL para copiar el resultado de esta búsqueda.'
  },
  'searchResult_delete_icon' => {
    'lastUpdated' => '1253308978',
    'message' => 'El ícono para eliminar este resultado de búsqueda.'
  },
  'searchResult_delete_url' => {
    'lastUpdated' => '1253308989',
    'message' => 'El URL para eliminar este resultado de búsqueda.'
  },
  'searchResult_edit_icon' => {
    'lastUpdated' => '1253309008',
    'message' => 'El ícono para editar que lleva a la pantalla de edición de este resultado de búsqueda.'
  },
  'searchResult_edit_url' => {
    'lastUpdated' => '1253309034',
    'message' => 'El URL a la pantalla de edición para este resultado de búsqueda.'
  },
  'searchResult_field_loop' => {
    'lastUpdated' => '1253309055',
    'message' => 'Un ciclo que contiene los campos que han de ser mostrados para este resultado de búsqueda.'
  },
  'searchResult_id' => {
    'lastUpdated' => '1253309066',
    'message' => 'El ID del resultado de búsqueda.'
  },
  'searchResult_loop' => {
    'lastUpdated' => '1253309077',
    'message' => 'Un ciclo que itera sobre los resultados de búsqueda.'
  },
  'searchResult_view_url' => {
    'lastUpdated' => '1253309093',
    'message' => 'El URL a la pantalla para ver este resultado de búsqueda.'
  },
  'searchScreenTitle' => {
    'lastUpdated' => '1253309106',
    'message' => 'El título de la pantalla de búsqueda.'
  },
  'search_url' => {
    'lastUpdated' => '1253309117',
    'message' => 'El URL que lleva a la pantalla de búsqueda.'
  },
  'size description' => {
    'lastUpdated' => '1253309138',
    'message' => 'Indique el ancho en caracteres de los campos.'
  },
  'size label' => {
    'lastUpdated' => '1253309145',
    'message' => 'Anchura'
  },
  'skip label' => {
    'lastUpdated' => '1253309151',
    'message' => 'Ignorar'
  },
  'sort by label' => {
    'lastUpdated' => '1253309158',
    'message' => 'Ordenar por'
  },
  'subtext description' => {
    'lastUpdated' => '1253309201',
    'message' => 'Un texto adicional a la etiqueta, posiblemente para describir lo que debe introducirse en el Campo. Será desplegado por debajo o después del elemento de formulario asociado al Campo.'
  },
  'subtext label' => {
    'lastUpdated' => '1253309220',
    'message' => 'Texto posterior'
  },
  'template_label' => {
    'lastUpdated' => '1253309272',
    'message' => 'Plantilla para Lista de Cosas'
  },
  'thing must have fields' => {
    'lastUpdated' => '1253309296',
    'message' => 'Error: Debe definir Campos para su Cosa.'
  },
  'thing name description' => {
    'lastUpdated' => '1253309326',
    'message' => 'Un nombre para esta cosa, con significado para un humano.'
  },
  'thing name label' => {
    'lastUpdated' => '1253309367',
    'message' => 'Nombre de la Cosa'
  },
  'thing_addUrl' => {
    'lastUpdated' => '1253309395',
    'message' => 'Un enlace hacia la pantalla de agregar en esta Cosa'
  },
  'thing_copyIcon' => {
    'lastUpdated' => '1253309409',
    'message' => 'Un ícono con un enlace para copiar esta Cosa.'
  },
  'thing_copyUrl' => {
    'lastUpdated' => '1253309427',
    'message' => 'Un enlace para copiar esta Cosa.'
  },
  'thing_deleteIcon' => {
    'lastUpdated' => '1253309439',
    'message' => 'Un ícono con un enlace para eliminar esta Cosa.'
  },
  'thing_deleteUrl' => {
    'lastUpdated' => '1253309456',
    'message' => 'Un enlace para eliminar esta Cosa.'
  },
  'thing_editIcon' => {
    'lastUpdated' => '1253309471',
    'message' => 'Un ícono con un enlace a la pantalla de editar esta Cosa.'
  },
  'thing_editUrl' => {
    'lastUpdated' => '1253309488',
    'message' => 'Un enlace a la pantalla de editar esta Cosa.'
  },
  'thing_id' => {
    'lastUpdated' => '1253309500',
    'message' => 'El ID de esta Cosa.'
  },
  'thing_label' => {
    'lastUpdated' => '1253309520',
    'message' => 'La etiqueta para esta Cosa.'
  },
  'thing_searchUrl' => {
    'lastUpdated' => '1253309541',
    'message' => 'Un enlace a la página de búsqueda de esta Cosa.'
  },
  'thing_viewIcon' => {
    'lastUpdated' => '1253309559',
    'message' => 'Un ícono con un enlace a la pantalla por omisión de esta Cosa.'
  },
  'things per page description' => {
    'lastUpdated' => '1253309590',
    'message' => 'El número de Cosas por página a mostrar en la pantalla de búsqueda.'
  },
  'things per page label' => {
    'lastUpdated' => '1253309598',
    'message' => 'Cosas por Página'
  },
  'things_loop' => {
    'lastUpdated' => '1253309627',
    'message' => 'Un ciclo que itera sobre todas las Cosas definidas en el Activo, con enlaces hacia las funciones administrativas de esas Cosas.'
  },
  'thingy asset template variables body' => {
    'lastUpdated' => '1253309759',
    'message' => 'Cada Activo provee un conjunto de variables que son accesibles desde sus Plantillas y que permiten acceder a las propiedades internas. Algunas variables son más útiles que otras.'
  },
  'thingy asset template variables title' => {
    'lastUpdated' => '1253309783',
    'message' => 'Variables para Plantillas de Cosas'
  },
  'thingy template description' => {
    'lastUpdated' => '1253309798',
    'message' => 'Seleccione la Plantilla para la Cosa.'
  },
  'thingy template label' => {
    'lastUpdated' => '1253309806',
    'message' => 'Plantilla para la Cosa'
  },
  'vertical description' => {
    'lastUpdated' => '1253309830',
    'message' => 'Esta propiedad controla la disposición vertical u horizontal de los botones radio y checklists.'
  },
  'vertical label' => {
    'lastUpdated' => '1253309838',
    'message' => 'Vertical'
  },
  'view last edited label' => {
    'lastUpdated' => '1253309856',
    'message' => 'Ver última edición/agregado'
  },
  'view screen tab label' => {
    'lastUpdated' => '1253309868',
    'message' => 'Pantalla para Ver'
  },
  'view screen title label' => {
    'lastUpdated' => '1253309879',
    'message' => 'Título de Pantalla para Ver'
  },
  'view template description' => {
    'lastUpdated' => '1253309898',
    'message' => 'Seleccione la Plantilla para desplegar la pantalla de ver esta Cosa.'
  },
  'view template label' => {
    'lastUpdated' => '1253309907',
    'message' => 'Plantilla para Ver'
  },
  'view thing template label' => {
    'lastUpdated' => '1253309928',
    'message' => 'Plantilla para Ver Cosa'
  },
  'view thingy default label' => {
    'lastUpdated' => '1253309948',
    'message' => 'Vista por Omisión'
  },
  'viewScreenTitle' => {
    'lastUpdated' => '1253309965',
    'message' => 'El título para la pantalla de ver Cosa.'
  },
  'view_url' => {
    'lastUpdated' => '1253309981',
    'message' => 'El URL que lleva hacia la vista por omisión de la Cosa.'
  },
  'who can add description' => {
    'lastUpdated' => '1253310001',
    'message' => 'El Grupo que puede agregar a esta Cosa.'
  },
  'who can add label' => {
    'lastUpdated' => '1253310103',
    'message' => '¿Quién puede agregar?'
  },
  'who can edit description' => {
    'lastUpdated' => '1253310075',
    'message' => 'Seleccione "<strong>Dueño"</strong> si los datos de esta Cosa solamente pueden ser editados por la persona que lo agregó o un grupo que puede editar los datos de la cosa. Cualquier usuario que pueda editar el Activo contenedor siempre podra ver y editar los datos.'
  },
  'who can edit label' => {
    'lastUpdated' => '1253310092',
    'message' => '¿Quién puede editar?'
  },
  'who can export description' => {
    'lastUpdated' => '1253310114',
    'message' => 'El Grupo que puede exportar datos de esta Cosa.'
  },
  'who can export label' => {
    'lastUpdated' => '1253310121',
    'message' => '¿Quién puede exportar?'
  },
  'who can import description' => {
    'lastUpdated' => '1253310131',
    'message' => 'El Grupo que puede importar datos en esta Cosa.'
  },
  'who can import label' => {
    'lastUpdated' => '1253310141',
    'message' => '¿Quién puede importar?'
  },
  'who can search description' => {
    'lastUpdated' => '1253310155',
    'message' => 'El Grupo que puede buscar sobre esta Cosa.'
  },
  'who can search label' => {
    'lastUpdated' => '1253310166',
    'message' => '¿Quién puede buscar?'
  },
  'who can view description' => {
    'lastUpdated' => '1253310201',
    'message' => 'Seleccione "<strong>Dueño"</strong> si los datos de esta Cosa solamente pueden
ser vistos por la persona que lo agregó o un grupo que puede ver
los datos de la cosa. Cualquier usuario que pueda editar el Activo
contenedor siempre podra ver y editar los datos.'
  },
  'who can view label' => {
    'lastUpdated' => '1253310209',
    'message' => '¿Quién puede ver?'
  },
  'width description' => {
    'lastUpdated' => '1253310225',
    'message' => 'Defina la anchura en pixels de TextAreas y HTMLAreas.'
  },
  'width label' => {
    'lastUpdated' => '1253310232',
    'message' => 'Anchura'
  }
}
;

1;
